/*
Hello world example plugin

@copyright (c) Copyright 2019 Dorian Pula
@license Apache-2.0
@author Dorian Pula [dorian.pula@amber-penguin-software.ca]
*/

const tagName = "dark-mode-switch";
const darkTheme = "dark";
const lightTheme = "light";
const themeAttribute = "theme";
const style = `
<style>
  ${tagName} > div {
    display: inline-flex;
    align-items: center;
    
    border-radius: 10px;
    border-width: 2px;
    border-style: solid;
    padding: 10px;
    
    font-size: 16px;
    font-family: "Arial", "sans-serif";
    font-weight: bold;
  }
  
  ${tagName}> div > span.theme-switcher-icon {
    font-size: 24px;
    font-weight: bolder;
    padding-right: 5px;
  }
  
  body.dark ${tagName} > div,
  body.light ${tagName} > div:hover {
    background-color: var(--dark-element-background);
    color: var(--dark-element);
    border-color: var(--dark-element);
  }
  
  body.light ${tagName} > div,
  body.dark ${tagName} > div:hover {
    background-color: var(--light-element-background);
    color: var(--light-element);
    border-color: var(--light-element);
  }
</style>\n
`;

class DarkModeSwitch extends HTMLElement {
  getCurrentTheme() {
    return this.getAttribute(themeAttribute) || lightTheme;
  }

  isDarkInMode() {
    return this.getCurrentTheme() !== lightTheme;
  }

  getNextTheme() {
    return this.getCurrentTheme() === lightTheme ? darkTheme : lightTheme;
  }

  connectedCallback() {
    this.renderElement();
    this.addEventListener("click", () => {this.toggleTheme()});
  }

  renderElement() {
    const icon = !this.isDarkInMode() ? "☾" : "☼";
    this.innerHTML = `
      ${style}
      <div>
        <span class="theme-switcher-icon">${icon}</span>
        <span class="theme-switcher-message">Switch to ${this.getNextTheme()} mode</span>
      </div>`;

    if (document.body.classList.contains(this.getNextTheme())) {
      document.body.classList.remove(this.getNextTheme());
    }
    document.body.classList.add(this.getCurrentTheme());
  }

  toggleTheme() {
    let nextTheme = this.getNextTheme();
    this.setAttribute(themeAttribute, nextTheme);
    this.renderElement();
  }

}

if (customElements.get(tagName) === undefined) {
  customElements.define(tagName, DarkModeSwitch);
}
