import path from "path";
import webpack from "webpack";
import HtmlWebpackPlugin from "html-webpack-plugin";

const ENV = process.env.NODE_ENV || "development";

export default {
  entry: ["./src/plugin.js"],
  output: {
    path: path.resolve(__dirname, "dist"),
    filename: "dark-mode-switch-plugin.js"
  },

  module: {

    rules: [
      {
        enforce: "pre",
        test: /\.js$/,
        exclude: [
          /node_modules/,
        ],
        loader: "eslint-loader",
        options: {
          emitWarning: true
        }
      },
      {
        test: /\.js/,
        include: [
          path.resolve(__dirname, "src"),
        ],
        exclude: [
          /node_modules/,
        ],

        loader: "babel-loader",
      },
    ]
  },

  devtool: ENV === "production" ? "source-map" : "cheap-module-eval-source-map",
  mode: ENV,

  devServer: {
    contentBase: [path.join(__dirname), path.join(__dirname, "dist") ],
    historyApiFallback: true,
    host: "0.0.0.0",
    hot: true,
    inline: true,
    port: 3000,
  },

  plugins: ([
    new webpack.NoEmitOnErrorsPlugin(),
    new webpack.HotModuleReplacementPlugin(),
    new HtmlWebpackPlugin({
      template: "./index.html",
      xhtml: true,
    }),
  ])
};
