extern crate chrono;
extern crate log;
extern crate serde;
#[macro_use]
extern crate serde_derive;
extern crate serde_json;
extern crate uuid;

use std::collections::HashMap;
use std::default::Default;

use chrono::{DateTime, Utc};
use serde_json::Value;

#[derive(Serialize, Deserialize, Clone, Debug)]
pub struct Page {
    pub slug: String,
    pub title: String,
    pub content: String,
    #[serde(rename = "created", skip_deserializing)]
    pub created_at: Option<DateTime<Utc>>,
}

impl Default for Page {
    fn default() -> Page {
        Page {
            title: Default::default(),
            slug: Default::default(),
            content: Default::default(),
            created_at: None,
        }
    }
}

#[derive(Serialize, Deserialize, Clone, Debug)]
pub struct Site {
    pub name: String,
    pub index: Option<String>,
    pub pages: Option<HashMap<String, Value>>,
}

impl Default for Site {
    fn default() -> Site {
        Site {
            name: Default::default(),
            index: Default::default(),
            pages: Some(HashMap::new()),
        }
    }
}
