import path from "path";
import HtmlWebpackPlugin from "html-webpack-plugin";
import webpack from "webpack";
import CopyPlugin from "copy-webpack-plugin";

const ENV = process.env.NODE_ENV || "development";

export default {
  mode: ENV,
  entry: ["./src/index.js"],
  output: {
    path: path.resolve(__dirname, "dist"),
    filename: "rookeries.js",
  },

  module: {

    rules: [
      {
        enforce: "pre",
        test: /\.js$/,
        exclude: [
          /node_modules/,
        ],
        loader: "eslint-loader",
        options: {
          emitWarning: true,
        }
      },
      {
        test: /\.js/,
        include: [
          path.resolve(__dirname, "src"),
        ],
        exclude: [
          /node_modules/,
        ],

        loader: "babel-loader",
      },
      {
        test: /\.css$/,
        loader: "css-loader",
      },
      {
        test: /\.html/,
        loader: "html-loader",
      },
    ]
  },

  devtool: ENV === "production" ? "source-map" : "cheap-module-eval-source-map",

  devServer: {
    contentBase: "./",
    historyApiFallback: true,
    host: "0.0.0.0",
    hot: true,
    port: 3000,
    writeToDisk: true,
  },

  plugins: ([
    new webpack.NoEmitOnErrorsPlugin(),new HtmlWebpackPlugin({
      title: "Rookeries - Webpack Dev",
      template: "./index.html",
      xhtml: true,
    }),
    new webpack.HotModuleReplacementPlugin(),
    new CopyPlugin([
      { from: "dev-stubs", to: "api" },
    ]),
  ])
};
